Switch from NDNx to CCNx

Change-Id: Icc2e6dd95d9c4e0ba22b7efb9933c1db7194842e
diff --git a/adhoc/adhoc-osx.mm b/adhoc/adhoc-osx.mm
index c3116f4..7d2b1df 100644
--- a/adhoc/adhoc-osx.mm
+++ b/adhoc/adhoc-osx.mm
@@ -70,10 +70,10 @@
 
   _LOG_DEBUG ("Creating face for the adhoc connection");
 
   // should do a better job later, when Ccnx::Control will be implemented
 
   ostringstream cmd;
-  cmd << CCNX_PATH << "/bin/ccndc add / udp 169.254.255.255";
+  cmd << NDNX_PATH << "/bin/ndndc add / udp 169.254.255.255";
   int ret = system (cmd.str ().c_str ());
   if (ret == 0)
     {
@@ -70,10 +70,10 @@
   _LOG_DEBUG ("Creating face for the adhoc connection");
 
-  // should do a better job later, when Ccnx::Control will be implemented
+  // should do a better job later, when Ndnx::Control will be implemented
 
   ostringstream cmd;